sieve
=====

XML Comparison Utils

Ripped from `FormEncode <http://pypi.python.org/pypi/FormEncode>`_ and
`strainer <http://pypi.python.org/pypi/strainer>`_ just to support Python3.
Intended for use in your webapp test suites.
